On Fri, 2017-09-29 at 01:35 +0530, Gargi Sharma wrote: > On Thu, Sep 28, 2017 at 3:46 PM, Rik van Riel > wrote: > > On Fri, 2017-09-29 at 01:09 +0530, Gargi Sharma wrote: > > > > > 1000 processes that just sleep and sit around without doing > > > anything(100 second sleep and then exit). > > > > Is that with or without your patches? > > > > How does it compare to a kernel with(out) your patches? > > Ah thanks for pointing this out. Those were without the patches. > Here are the stats for easier comparison. > > With Patches                 Without patches > pstree > real    0m0.542s            real    0m0.859s > user    0m0.335s           user    0m0.536s > sys    0m0.150s             sys    0m0.172s > > ps > real    0m0.722s            real    0m0.918s > user    0m0.064s           user    0m0.100s > sys    0m0.162s             sys    0m0.172s > > readdir > real    0m0.080s           real    0m0.092s > user    0m0.000s          user    0m0.000s > sys    0m0.021s            sys    0m0.020s So your patches speed up the use of /proc? I suspect pstree and ps benefit from the simplification and speedup of find_pid_ns, which is called from find_task_by_pid_ns. That is great news. -- All Rights Reversed.